@@ -9,7 +9,7 @@
 #include "internal/loaders.h"
 
 static bool claim_bytes(size_t required, size_t provided,
-                        struct cbor_decoder_result *result) {
+                        struct cbor_decoder_result* result) {
   if (required > (provided - result->read)) {
     result->required = required + result->read;
     result->read = 0;
@@ -42,7 +42,7 @@ static bool claim_bytes(size_t required, size_t provided,
 
 struct cbor_decoder_result cbor_stream_decode(
     cbor_data source, size_t source_size,
-    const struct cbor_callbacks *callbacks, void *context) {
+    const struct cbor_callbacks* callbacks, void* context) {
   // Attempt to claim the initial MTB byte
   struct cbor_decoder_result result = {.status = CBOR_DECODER_FINISHED};
   if (!claim_bytes(1, source_size, &result)) {
@@ -437,23 +437,21 @@ struct cbor_decoder_result cbor_stream_decode(
         callbacks->indef_map_start(context);
         return result;
       }
-    case 0xC0:
-      /* Text date/time - RFC 3339 tag, fallthrough */
-    case 0xC1:
-      /* Epoch date tag, fallthrough */
-    case 0xC2:
-      /* Positive bignum tag, fallthrough */
-    case 0xC3:
-      /* Negative bignum tag, fallthrough */
-    case 0xC4:
-      /* Fraction, fallthrough */
-    case 0xC5:
-      /* Big float */
-      {
-        callbacks->tag(context, (uint64_t)(_cbor_load_uint8(source) -
-                                           0xC0)); /* 0xC0 offset */
-        return result;
-      }
+      /* See https://www.iana.org/assignments/cbor-tags/cbor-tags.xhtml for tag
+       * assignment. All well-formed tags are processed regardless of validity
+       * since maintaining the known mapping would be impractical.
+       *
+       * Moreover, even tags in the reserved "standard" range are not assigned
+       * but may get assigned in the future (see e.g.
+       * https://github.com/PJK/libcbor/issues/307), so processing all tags
+       * improves forward compatibility.
+       */
+    case 0xC0: /* Fallthrough */
+    case 0xC1: /* Fallthrough */
+    case 0xC2: /* Fallthrough */
+    case 0xC3: /* Fallthrough */
+    case 0xC4: /* Fallthrough */
+    case 0xC5: /* Fallthrough */
     case 0xC6: /* Fallthrough */
     case 0xC7: /* Fallthrough */
     case 0xC8: /* Fallthrough */
@@ -468,13 +466,10 @@ struct cbor_decoder_result cbor_stream_decode(
     case 0xD1: /* Fallthrough */
     case 0xD2: /* Fallthrough */
     case 0xD3: /* Fallthrough */
-    case 0xD4: /* Unassigned tag value */
-    {
-      return (struct cbor_decoder_result){.status = CBOR_DECODER_ERROR};
-    }
-    case 0xD5: /* Expected b64url conversion tag - fallthrough */
-    case 0xD6: /* Expected b64 conversion tag - fallthrough */
-    case 0xD7: /* Expected b16 conversion tag */
+    case 0xD4: /* Fallthrough */
+    case 0xD5: /* Fallthrough */
+    case 0xD6: /* Fallthrough */
+    case 0xD7: /* Fallthrough */
     {
       callbacks->tag(context, (uint64_t)(_cbor_load_uint8(source) -
                                          0xC0)); /* 0xC0 offset */
@@ -597,9 +592,10 @@ struct cbor_decoder_result cbor_stream_decode(
     case 0xFF:
       /* Break */
       callbacks->indef_break(context);
-      // Never happens, the switch statement is exhaustive on the 1B range; make
-      // compiler happy
+      return result;
     default:
+      // Never happens, the switch statement is exhaustive on the 1B range
+      _CBOR_UNREACHABLE;
       return result;
   }
 }
